@@ -1,5 +1,6 @@
 import json
 from pathlib import Path
+import re
 from typing import Optional
 
 import pytest
@@ -25,7 +26,8 @@ def test_basic_search(py_client: RgdClient, spatial_asset_a):
     }
 
     q = py_client.rgd.search(query=json.dumps(bbox), predicate='intersects')
-    assert len(q) == 1
+    assert q['count'] == 1
+    assert len(q['results']) == 1
 
 
 @pytest.mark.django_db(transaction=True)
@@ -221,3 +223,56 @@ def test_file_download_keep_existing(
         checksum_file.id, tmp_path, keep_existing=False, use_id=True
     )
     assert existing_file_content != file_path.read_bytes()
+
+
+@pytest.mark.django_db(transaction=True)
+def test_create_collection_new(py_client: RgdClient):
+    """Test that creating a new collection succeeds."""
+    assert Collection.objects.count() == 0
+
+    r = py_client.rgd.create_collection('test')
+    assert r == {
+        'id': Collection.objects.order_by('-id').first().id,
+        'name': 'test',
+        'description': None,
+    }
+
+    assert Collection.objects.count() == 1
+
+
+@pytest.mark.django_db(transaction=True)
+def test_create_collection_existing(py_client: RgdClient, collection: Collection):
+    """Test that attempting to create an existing collection simply returns the existing one."""
+    collection_count = Collection.objects.count()
+
+    r = py_client.rgd.create_collection(collection.name)
+
+    assert r == {
+        'id': collection.id,
+        'name': collection.name,
+        'description': collection.description,
+    }
+
+    # Ensure that no new collections have been created
+    assert Collection.objects.count() == collection_count
+
+
+@pytest.mark.django_db(transaction=True)
+def test_get_collection_by_name_exists(py_client: RgdClient, collection: Collection):
+    r = py_client.rgd.get_collection_by_name(collection.name)
+
+    assert r == {
+        'id': collection.id,
+        'name': collection.name,
+        'description': collection.description,
+    }
+
+
+@pytest.mark.django_db(transaction=True)
+def test_get_collection_by_name_nonexistant(py_client: RgdClient, collection: Collection):
+    nonexistant_collection_name = f'not_{collection.name}'
+
+    with pytest.raises(ValueError) as error:
+        py_client.rgd.get_collection_by_name(nonexistant_collection_name)
+
+    assert error.match(re.escape(rf'Collection ({nonexistant_collection_name}) cannot be found.'))
